@@ -5,6 +5,7 @@ import marshmallow_sqlalchemy as msa
 from bemserver_core.model import EnergyConsumptionTimeseriesByBuilding
 
 from bemserver_api import AutoSchema, Schema
+from ..timeseries.schemas import TimeseriesSchema
 
 
 class EnergyConsumptionTimeseriesByBuildingSchema(AutoSchema):
@@ -12,7 +13,7 @@ class EnergyConsumptionTimeseriesByBuildingSchema(AutoSchema):
         model = EnergyConsumptionTimeseriesByBuilding
 
     id = msa.auto_field(dump_only=True)
-    wh_conversion_factor = msa.auto_field(metadata={"default": 1})
+    timeseries = ma.fields.Nested(TimeseriesSchema(exclude=("id",)), dump_only=True)
 
 
 class EnergyConsumptionTimeseriesByBuildingQueryArgsSchema(Schema):
