@@ -11,7 +11,7 @@ from bemserver_core.model import (
     UserGroupByCampaignScope,
     Timeseries,
     TimeseriesDataState,
-    EnergySource,
+    Energy,
     EnergyEndUse,
     EnergyConsumptionTimeseriesBySite,
     EnergyConsumptionTimeseriesByBuilding,
@@ -41,6 +41,7 @@ class TestAnalysisApiEnergyConsumption:
                 name=f"Timeseries {i+1}",
                 campaign_id=campaign_id,
                 campaign_scope_id=campaign_scope_id,
+                unit_symbol=("Wh" if i < 6 else "kWh"),
             )
             timeseries.append(ts_i)
         db.session.add_all(timeseries)
@@ -116,69 +117,66 @@ class TestAnalysisApiEnergyConsumption:
                 campaign_1_id, cs_1_id
             )
 
-            source_all = EnergySource.get(name="all").first()
-            source_elec = EnergySource.get(name="electricity").first()
-            source_gas = EnergySource.get(name="natural gas").first()
+            energy_all = Energy.get(name="all").first()
+            energy_elec = Energy.get(name="electricity").first()
+            energy_gas = Energy.get(name="natural gas").first()
             end_use_all = EnergyEndUse.get(name="all").first()
             end_use_heating = EnergyEndUse.get(name="heating").first()
             end_use_cooling = EnergyEndUse.get(name="cooling").first()
 
             ectbs_all_all = EnergyConsumptionTimeseriesBySite.new(
                 site_id=sites[0],
-                source_id=source_all.id,
+                energy_id=energy_all.id,
                 end_use_id=end_use_all.id,
                 timeseries_id=timeseries[0].id,
             )
             ectbs_all_heating = EnergyConsumptionTimeseriesBySite.new(
                 site_id=sites[0],
-                source_id=source_all.id,
+                energy_id=energy_all.id,
                 end_use_id=end_use_heating.id,
                 timeseries_id=timeseries[1].id,
             )
             ectbs_all_cooling = EnergyConsumptionTimeseriesBySite.new(
                 site_id=sites[0],
-                source_id=source_all.id,
+                energy_id=energy_all.id,
                 end_use_id=end_use_cooling.id,
                 timeseries_id=timeseries[2].id,
             )
             ectbs_elec_all = EnergyConsumptionTimeseriesBySite.new(
                 site_id=sites[0],
-                source_id=source_elec.id,
+                energy_id=energy_elec.id,
                 end_use_id=end_use_all.id,
                 timeseries_id=timeseries[3].id,
             )
             ectbs_elec_heating = EnergyConsumptionTimeseriesBySite.new(
                 site_id=sites[0],
-                source_id=source_elec.id,
+                energy_id=energy_elec.id,
                 end_use_id=end_use_heating.id,
                 timeseries_id=timeseries[4].id,
             )
             ectbs_elec_cooling = EnergyConsumptionTimeseriesBySite.new(
                 site_id=sites[0],
-                source_id=source_elec.id,
+                energy_id=energy_elec.id,
                 end_use_id=end_use_cooling.id,
                 timeseries_id=timeseries[5].id,
             )
             ectbs_gas_all = EnergyConsumptionTimeseriesBySite.new(
                 site_id=sites[0],
-                source_id=source_gas.id,
+                energy_id=energy_gas.id,
                 end_use_id=end_use_all.id,
                 timeseries_id=timeseries[6].id,
-                wh_conversion_factor=1000,
             )
             ectbs_gas_heating = EnergyConsumptionTimeseriesBySite.new(
                 site_id=sites[0],
-                source_id=source_gas.id,
+                energy_id=energy_gas.id,
                 end_use_id=end_use_heating.id,
                 timeseries_id=timeseries[7].id,
-                wh_conversion_factor=1000,
             )
             ectbs_gas_cooling = EnergyConsumptionTimeseriesBySite.new(
                 site_id=sites[0],
-                source_id=source_gas.id,
+                energy_id=energy_gas.id,
                 end_use_id=end_use_cooling.id,
                 timeseries_id=timeseries[8].id,
-                wh_conversion_factor=1000,
             )
             db.session.add_all(
                 (
@@ -213,8 +211,34 @@ class TestAnalysisApiEnergyConsumption:
                 ret_data = ret.json
                 assert ret_data == expected
 
+        # Wrong unit
         with OpenBar():
-            # Remove user <-> timeseries association
+            timeseries[0].unit_symbol = ""
+            db.session.add(timeseries[0])
+            db.session.commit()
+
+        with auth_context:
+            ret = client.get(
+                query_url,
+                query_string={
+                    "start_time": start_time.isoformat(),
+                    "end_time": end_time.isoformat(),
+                    "bucket_width_value": 1,
+                    "bucket_width_unit": "hour",
+                    "timezone": "UTC",
+                },
+            )
+            if user == "anonym":
+                assert ret.status_code == 401
+            else:
+                assert ret.status_code == 409
+                ret_data = ret.json
+                assert ret_data["message"] == "Incompatible unit in input timeseries."
+
+        # Without user <-> timeseries association
+        with OpenBar():
+            timeseries[0].unit_symbol = "Wh"
+            db.session.add(timeseries[0])
             ugbcs_1 = UserGroupByCampaignScope.get(campaign_scope_id=cs_1_id).first()
             ugbcs_1.delete()
             db.session.commit()
@@ -279,69 +303,66 @@ class TestAnalysisApiEnergyConsumption:
                 campaign_1_id, cs_1_id
             )
 
-            source_all = EnergySource.get(name="all").first()
-            source_elec = EnergySource.get(name="electricity").first()
-            source_gas = EnergySource.get(name="natural gas").first()
+            energy_all = Energy.get(name="all").first()
+            energy_elec = Energy.get(name="electricity").first()
+            energy_gas = Energy.get(name="natural gas").first()
             end_use_all = EnergyEndUse.get(name="all").first()
             end_use_heating = EnergyEndUse.get(name="heating").first()
             end_use_cooling = EnergyEndUse.get(name="cooling").first()
 
             ectbs_all_all = EnergyConsumptionTimeseriesByBuilding.new(
                 building_id=buildings[0],
-                source_id=source_all.id,
+                energy_id=energy_all.id,
                 end_use_id=end_use_all.id,
                 timeseries_id=timeseries[0].id,
             )
             ectbs_all_heating = EnergyConsumptionTimeseriesByBuilding.new(
                 building_id=buildings[0],
-                source_id=source_all.id,
+                energy_id=energy_all.id,
                 end_use_id=end_use_heating.id,
                 timeseries_id=timeseries[1].id,
             )
             ectbs_all_cooling = EnergyConsumptionTimeseriesByBuilding.new(
                 building_id=buildings[0],
-                source_id=source_all.id,
+                energy_id=energy_all.id,
                 end_use_id=end_use_cooling.id,
                 timeseries_id=timeseries[2].id,
             )
             ectbs_elec_all = EnergyConsumptionTimeseriesByBuilding.new(
                 building_id=buildings[0],
-                source_id=source_elec.id,
+                energy_id=energy_elec.id,
                 end_use_id=end_use_all.id,
                 timeseries_id=timeseries[3].id,
             )
             ectbs_elec_heating = EnergyConsumptionTimeseriesByBuilding.new(
                 building_id=buildings[0],
-                source_id=source_elec.id,
+                energy_id=energy_elec.id,
                 end_use_id=end_use_heating.id,
                 timeseries_id=timeseries[4].id,
             )
             ectbs_elec_cooling = EnergyConsumptionTimeseriesByBuilding.new(
                 building_id=buildings[0],
-                source_id=source_elec.id,
+                energy_id=energy_elec.id,
                 end_use_id=end_use_cooling.id,
                 timeseries_id=timeseries[5].id,
             )
             ectbs_gas_all = EnergyConsumptionTimeseriesByBuilding.new(
                 building_id=buildings[0],
-                source_id=source_gas.id,
+                energy_id=energy_gas.id,
                 end_use_id=end_use_all.id,
                 timeseries_id=timeseries[6].id,
-                wh_conversion_factor=1000,
             )
             ectbs_gas_heating = EnergyConsumptionTimeseriesByBuilding.new(
                 building_id=buildings[0],
-                source_id=source_gas.id,
+                energy_id=energy_gas.id,
                 end_use_id=end_use_heating.id,
                 timeseries_id=timeseries[7].id,
-                wh_conversion_factor=1000,
             )
             ectbs_gas_cooling = EnergyConsumptionTimeseriesByBuilding.new(
                 building_id=buildings[0],
-                source_id=source_gas.id,
+                energy_id=energy_gas.id,
                 end_use_id=end_use_cooling.id,
                 timeseries_id=timeseries[8].id,
-                wh_conversion_factor=1000,
             )
             db.session.add_all(
                 (
@@ -376,8 +397,34 @@ class TestAnalysisApiEnergyConsumption:
                 ret_data = ret.json
                 assert ret_data == expected
 
+        # Wrong unit
         with OpenBar():
-            # Remove user <-> timeseries association
+            timeseries[0].unit_symbol = ""
+            db.session.add(timeseries[0])
+            db.session.commit()
+
+        with auth_context:
+            ret = client.get(
+                query_url,
+                query_string={
+                    "start_time": start_time.isoformat(),
+                    "end_time": end_time.isoformat(),
+                    "bucket_width_value": 1,
+                    "bucket_width_unit": "hour",
+                    "timezone": "UTC",
+                },
+            )
+            if user == "anonym":
+                assert ret.status_code == 401
+            else:
+                assert ret.status_code == 409
+                ret_data = ret.json
+                assert ret_data["message"] == "Incompatible unit in input timeseries."
+
+        # Without user <-> timeseries association
+        with OpenBar():
+            timeseries[0].unit_symbol = "Wh"
+            db.session.add(timeseries[0])
             ugbcs_1 = UserGroupByCampaignScope.get(campaign_scope_id=cs_1_id).first()
             ugbcs_1.delete()
             db.session.commit()
