@@ -12,14 +12,14 @@ SITES_URL = "/sites/"
 
 class TestEnergyConsumptionTimeseriesBySiteApi:
     def test_energy_consumption_timeseries_by_sites_api(
-        self, app, users, sites, timeseries, energy_sources, energy_end_uses
+        self, app, users, sites, timeseries, energies, energy_end_uses
     ):
         creds = users["Chuck"]["creds"]
         site_1_id = sites[0]
         site_2_id = sites[1]
         ts_1_id = timeseries[0]
         ts_2_id = timeseries[1]
-        energy_source_1_id = energy_sources[1]
+        energy_1_id = energies[1]
         energy_end_use_1_id = energy_end_uses[1]
 
         client = app.test_client()
@@ -34,15 +34,15 @@ class TestEnergyConsumptionTimeseriesBySiteApi:
             ectbs_1 = {
                 "site_id": site_1_id,
                 "timeseries_id": ts_1_id,
-                "source_id": energy_source_1_id,
+                "energy_id": energy_1_id,
                 "end_use_id": energy_end_use_1_id,
-                "wh_conversion_factor": 1,
             }
             ret = client.post(ENERGY_CONSUMPTION_TIMESERIES_BY_SITES_URL, json=ectbs_1)
             assert ret.status_code == 201
             ret_val = ret.json
             ectbs_1_id = ret_val.pop("id")
             ectbs_1_etag = ret.headers["ETag"]
+            assert "id" not in ret_val.pop("timeseries")
             assert ret_val == ectbs_1
 
             # POST violating unique constraint
@@ -64,6 +64,7 @@ class TestEnergyConsumptionTimeseriesBySiteApi:
             assert ret.headers["ETag"] == ectbs_1_etag
             ret_val = ret.json
             ret_val.pop("id")
+            assert "id" not in ret_val.pop("timeseries")
             assert ret_val == ectbs_1
 
             # PUT
@@ -77,6 +78,7 @@ class TestEnergyConsumptionTimeseriesBySiteApi:
             ret_val = ret.json
             ret_val.pop("id")
             ectbs_1_etag = ret.headers["ETag"]
+            assert "id" not in ret_val.pop("timeseries")
             assert ret_val == ectbs_1
 
             # PUT wrong ID -> 404
@@ -91,9 +93,8 @@ class TestEnergyConsumptionTimeseriesBySiteApi:
             ectbs_2 = {
                 "site_id": site_2_id,
                 "timeseries_id": ts_2_id,
-                "source_id": energy_source_1_id,
+                "energy_id": energy_1_id,
                 "end_use_id": energy_end_use_1_id,
-                "wh_conversion_factor": 1,
             }
             ret = client.post(ENERGY_CONSUMPTION_TIMESERIES_BY_SITES_URL, json=ectbs_2)
             ret_val = ret.json
@@ -175,7 +176,7 @@ class TestEnergyConsumptionTimeseriesBySiteApi:
         users,
         sites,
         timeseries,
-        energy_sources,
+        energies,
         energy_end_uses,
         energy_consumption_timeseries_by_sites,
     ):
@@ -183,7 +184,7 @@ class TestEnergyConsumptionTimeseriesBySiteApi:
         site_1_id = sites[0]
         ts_1_id = timeseries[0]
         ts_3_id = timeseries[2]
-        energy_source_1_id = energy_sources[1]
+        energy_1_id = energies[1]
         energy_end_use_1_id = energy_end_uses[1]
         ectbs_1_id = energy_consumption_timeseries_by_sites[0]
 
@@ -196,15 +197,15 @@ class TestEnergyConsumptionTimeseriesBySiteApi:
             ret_val = ret.json
             assert len(ret_val) == 1
             ectbs_1 = ret_val[0]
+            assert "id" not in ectbs_1.pop("timeseries")
             assert ectbs_1.pop("id") == ectbs_1_id
 
             # POST
             ectbs_3 = {
                 "site_id": site_1_id,
                 "timeseries_id": ts_1_id,
-                "source_id": energy_source_1_id,
+                "energy_id": energy_1_id,
                 "end_use_id": energy_end_use_1_id,
-                "wh_conversion_factor": 1,
             }
             ret = client.post(ENERGY_CONSUMPTION_TIMESERIES_BY_SITES_URL, json=ectbs_3)
             assert ret.status_code == 403
